@@ -24,14 +24,22 @@ from PIL import Image
         show_default=True,
         help="Resized output image"
         )
-def removebg(inputimage, outputimage):
+@click.option(
+		'-c',
+		'--color',
+		type=click.Tuple([int, int, int]),
+		default=(255, 255, 255),
+		show_default=True,
+		help="Color to be removed"
+		)
+def removebg(inputimage, outputimage, color):
 	inputimage = Image.open(inputimage)
 	img = inputimage.convert("RGBA")
 	datas = img.getdata()
 	newData = []
 
 	for item in datas:
-		if item[0] == 255 and item[1] == 255 and item[2] == 255:
+		if item[0] == color[0] and item[1] == color[1] and item[2] == color[2]:
 			newData.append((255, 255, 255, 0))
 		else:
 			newData.append(item)
